@@ -245,7 +245,7 @@ virDomainCapsEnumSet(virDomainCapsEnum *capsEnum,
         if (!val) {
             /* Integer overflow */
             virReportError(VIR_ERR_INTERNAL_ERROR,
-                           _("integer overflow on %1$s. Please contact the libvirt development team at libvir-list@redhat.com"),
+                           _("integer overflow on %1$s. Please contact the libvirt development team at devel@lists.libvirt.org"),
                            capsEnumName);
             return -1;
         }
