@@ -40,6 +40,9 @@ qemuBlockStorageSourceGetEffectiveStorageNodename(virStorageSource *src);
 const char *
 qemuBlockStorageSourceGetStorageNodename(virStorageSource *src);
 
+const char *
+qemuBlockStorageSourceGetSliceNodename(virStorageSource *src);
+
 const char *
 qemuBlockStorageSourceGetFormatNodename(virStorageSource *src);
 
@@ -66,8 +69,7 @@ qemuBlockStorageSourceSupportsConcurrentAccess(virStorageSource *src);
 typedef enum {
     QEMU_BLOCK_STORAGE_SOURCE_BACKEND_PROPS_LEGACY = 1 << 0,
     QEMU_BLOCK_STORAGE_SOURCE_BACKEND_PROPS_TARGET_ONLY = 1 << 1,
-    QEMU_BLOCK_STORAGE_SOURCE_BACKEND_PROPS_AUTO_READONLY = 1 << 2,
-    QEMU_BLOCK_STORAGE_SOURCE_BACKEND_PROPS_SKIP_UNMAP = 1 << 3,
+    QEMU_BLOCK_STORAGE_SOURCE_BACKEND_PROPS_EFFECTIVE_NODE = 1 << 2,
 } qemuBlockStorageSourceBackendPropsFlags;
 
 virJSONValue *
@@ -147,11 +149,6 @@ void
 qemuBlockStorageSourceAttachRollback(qemuMonitor *mon,
                                      qemuBlockStorageSourceAttachData *data);
 
-int
-qemuBlockStorageSourceDetachOneBlockdev(virDomainObj *vm,
-                                        virDomainAsyncJob asyncJob,
-                                        virStorageSource *src);
-
 struct _qemuBlockStorageSourceChainData {
     qemuBlockStorageSourceAttachData **srcdata;
     size_t nsrcdata;
@@ -261,11 +258,6 @@ qemuBlockBitmapsHandleCommitFinish(virStorageSource *topsrc,
                                    GHashTable *blockNamedNodeData,
                                    virJSONValue **actions);
 
-/* only for use in qemumonitorjsontest */
-int
-qemuBlockReopenFormatMon(qemuMonitor *mon,
-                         virStorageSource *src);
-
 int
 qemuBlockReopenReadWrite(virDomainObj *vm,
                          virStorageSource *src,
@@ -278,6 +270,9 @@ qemuBlockReopenReadOnly(virDomainObj *vm,
 bool
 qemuBlockStorageSourceNeedsStorageSliceLayer(const virStorageSource *src);
 
+bool
+qemuBlockStorageSourceNeedsFormatLayer(const virStorageSource *src);
+
 char *
 qemuBlockStorageSourceGetCookieString(virStorageSource *src);
 
