@@ -2396,7 +2396,7 @@ virPCIGetPhysicalFunction(const char *vf_sysfs_path,
 
     *pf = NULL;
 
-    virBuildPath(&device_link, vf_sysfs_path, "physfn");
+    device_link = g_build_filename(vf_sysfs_path, "physfn", NULL);
 
     if ((*pf = virPCIGetDeviceAddressFromSysfsLink(device_link))) {
         VIR_DEBUG("PF for VF device '%s': " VIR_PCI_DEVICE_ADDRESS_FMT,
@@ -2580,7 +2580,7 @@ virPCIGetNetName(const char *device_link_sysfs_path,
         return -1;
     }
 
-    virBuildPath(&pcidev_sysfs_net_path, device_link_sysfs_path, "net");
+    pcidev_sysfs_net_path = g_build_filename(device_link_sysfs_path, "net", NULL);
 
     if (virDirOpenQuiet(&dir, pcidev_sysfs_net_path) < 0) {
         /* this *isn't* an error - caller needs to check for netname == NULL */
